@@ -1,8 +1,6 @@
-begin
-  require "rinku"
-rescue LoadError => _
-  abort "Missing dependency 'rinku' for AutolinkFilter. See README.md for details."
-end
+# frozen_string_literal: true
+
+HTML::Pipeline.require_dependency('rinku', 'AutolinkFilter')
 
 module HTML
   class Pipeline
