@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 HTML::Pipeline.require_dependency('sanitize', 'SanitizationFilter')
 
 module HTML
@@ -33,7 +35,7 @@ module HTML
       TABLE_SECTIONS = Set.new(%w[thead tbody tfoot].freeze)
 
       # These schemes are the only ones allowed in <a href> attributes by default.
-      ANCHOR_SCHEMES = ['http', 'https', 'mailto', :relative, 'github-windows', 'github-mac'].freeze
+      ANCHOR_SCHEMES = ['http', 'https', 'mailto', 'xmpp', :relative, 'github-windows', 'github-mac', 'irc', 'ircs'].freeze
 
       # The main sanitization whitelist. Only these elements and attributes are
       # allowed through by default.
@@ -43,6 +45,7 @@ module HTML
           div ins del sup sub p ol ul table thead tbody tfoot blockquote
           dl dt dd kbd q samp var hr ruby rt rp li tr td th s strike summary
           details caption figure figcaption
+          abbr bdo cite dfn mark small span time wbr
         ].freeze,
         remove_contents: ['script'].freeze,
         attributes: {
@@ -73,7 +76,7 @@ module HTML
                   vspace width itemprop].freeze
         }.freeze,
         protocols: {
-          'a'          => { 'href' => ANCHOR_SCHEMES },
+          'a'          => { 'href' => ANCHOR_SCHEMES }.freeze,
           'blockquote' => { 'cite' => ['http', 'https', :relative].freeze },
           'del'        => { 'cite' => ['http', 'https', :relative].freeze },
           'ins'        => { 'cite' => ['http', 'https', :relative].freeze },
@@ -109,7 +112,7 @@ module HTML
       # protocols, and transformers from WHITELIST but with a more locked down
       # set of allowed elements.
       LIMITED = WHITELIST.merge(
-        elements: %w[b i strong em a pre code img ins del sup sub p ol ul li]
+        elements: %w[b i strong em a pre code img ins del sup sub mark abbr p ol ul li]
       )
 
       # Strip all HTML tags from the document.
